@@ -97,7 +97,7 @@ TZ = {
 	{ 'America/Cuiaba', '<-04>4' },
 	{ 'America/Curacao', 'AST4' },
 	{ 'America/Danmarkshavn', 'GMT0' },
-	{ 'America/Dawson', 'PST8PDT,M3.2.0,M11.1.0' },
+	{ 'America/Dawson', 'MST7' },
 	{ 'America/Dawson Creek', 'MST7' },
 	{ 'America/Denver', 'MST7MDT,M3.2.0,M11.1.0' },
 	{ 'America/Detroit', 'EST5EDT,M3.2.0,M11.1.0' },
@@ -108,7 +108,6 @@ TZ = {
 	{ 'America/Fort Nelson', 'MST7' },
 	{ 'America/Fortaleza', '<-03>3' },
 	{ 'America/Glace Bay', 'AST4ADT,M3.2.0,M11.1.0' },
-	{ 'America/Godthab', '<-03>3<-02>,M3.5.0/-2,M10.5.0/-1' },
 	{ 'America/Goose Bay', 'AST4ADT,M3.2.0,M11.1.0' },
 	{ 'America/Grand Turk', 'EST5EDT,M3.2.0,M11.1.0' },
 	{ 'America/Grenada', 'AST4' },
@@ -162,6 +161,7 @@ TZ = {
 	{ 'America/North Dakota/Beulah', 'CST6CDT,M3.2.0,M11.1.0' },
 	{ 'America/North Dakota/Center', 'CST6CDT,M3.2.0,M11.1.0' },
 	{ 'America/North Dakota/New Salem', 'CST6CDT,M3.2.0,M11.1.0' },
+	{ 'America/Nuuk', '<-03>3<-02>,M3.5.0/-2,M10.5.0/-1' },
 	{ 'America/Ojinaga', 'MST7MDT,M3.2.0,M11.1.0' },
 	{ 'America/Panama', 'EST5' },
 	{ 'America/Pangnirtung', 'EST5EDT,M3.2.0,M11.1.0' },
@@ -198,14 +198,14 @@ TZ = {
 	{ 'America/Toronto', 'EST5EDT,M3.2.0,M11.1.0' },
 	{ 'America/Tortola', 'AST4' },
 	{ 'America/Vancouver', 'PST8PDT,M3.2.0,M11.1.0' },
-	{ 'America/Whitehorse', 'PST8PDT,M3.2.0,M11.1.0' },
+	{ 'America/Whitehorse', 'MST7' },
 	{ 'America/Winnipeg', 'CST6CDT,M3.2.0,M11.1.0' },
 	{ 'America/Yakutat', 'AKST9AKDT,M3.2.0,M11.1.0' },
 	{ 'America/Yellowknife', 'MST7MDT,M3.2.0,M11.1.0' },
-	{ 'Antarctica/Casey', '<+08>-8' },
+	{ 'Antarctica/Casey', '<+11>-11' },
 	{ 'Antarctica/Davis', '<+07>-7' },
 	{ 'Antarctica/DumontDUrville', '<+10>-10' },
-	{ 'Antarctica/Macquarie', '<+11>-11' },
+	{ 'Antarctica/Macquarie', 'AEST-10AEDT,M10.1.0,M4.1.0/3' },
 	{ 'Antarctica/Mawson', '<+05>-5' },
 	{ 'Antarctica/McMurdo', 'NZST-12NZDT,M9.5.0,M4.1.0/3' },
 	{ 'Antarctica/Palmer', '<-03>3' },
@@ -239,8 +239,8 @@ TZ = {
 	{ 'Asia/Dubai', '<+04>-4' },
 	{ 'Asia/Dushanbe', '<+05>-5' },
 	{ 'Asia/Famagusta', 'EET-2EEST,M3.5.0/3,M10.5.0/4' },
-	{ 'Asia/Gaza', 'EET-2EEST,M3.5.5/0,M10.5.6/1' },
-	{ 'Asia/Hebron', 'EET-2EEST,M3.5.5/0,M10.5.6/1' },
+	{ 'Asia/Gaza', 'EET-2EEST,M3.4.4/48,M10.4.4/49' },
+	{ 'Asia/Hebron', 'EET-2EEST,M3.4.4/48,M10.4.4/49' },
 	{ 'Asia/Ho Chi Minh', '<+07>-7' },
 	{ 'Asia/Hong Kong', 'HKT-8' },
 	{ 'Asia/Hovd', '<+07>-7' },
@@ -310,7 +310,6 @@ TZ = {
 	{ 'Australia/Adelaide', 'ACST-9:30ACDT,M10.1.0,M4.1.0/3' },
 	{ 'Australia/Brisbane', 'AEST-10' },
 	{ 'Australia/Broken Hill', 'ACST-9:30ACDT,M10.1.0,M4.1.0/3' },
-	{ 'Australia/Currie', 'AEST-10AEDT,M10.1.0,M4.1.0/3' },
 	{ 'Australia/Darwin', 'ACST-9:30' },
 	{ 'Australia/Eucla', '<+0845>-8:45' },
 	{ 'Australia/Hobart', 'AEST-10AEDT,M10.1.0,M4.1.0/3' },
@@ -401,7 +400,7 @@ TZ = {
 	{ 'Europe/Vatican', 'CET-1CEST,M3.5.0,M10.5.0/3' },
 	{ 'Europe/Vienna', 'CET-1CEST,M3.5.0,M10.5.0/3' },
 	{ 'Europe/Vilnius', 'EET-2EEST,M3.5.0/3,M10.5.0/4' },
-	{ 'Europe/Volgograd', '<+04>-4' },
+	{ 'Europe/Volgograd', '<+03>-3' },
 	{ 'Europe/Warsaw', 'CET-1CEST,M3.5.0,M10.5.0/3' },
 	{ 'Europe/Zagreb', 'CET-1CEST,M3.5.0,M10.5.0/3' },
 	{ 'Europe/Zaporozhye', 'EET-2EEST,M3.5.0/3,M10.5.0/4' },
